#' @details 
#' Implemention of a Bayesian estimation for the 
#' reduced Reparameterized Unified Model (rRUM).
#' @template rrum-references
#' @aliases rrum-package
#' @keywords internal
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
#' @useDynLib rrum, .registration=TRUE
#' @importFrom Rcpp evalCpp
#' @importFrom simcdm attribute_bijection attribute_classes sim_rrum_items
## usethis namespace: end
NULL
